#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_GREATER_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_GREATER_HPP_INCLUDED

#include <boost/simd/operator/include/functions/scalar/is_greater.hpp>

#endif
